@@ -39,8 +39,8 @@
 #include <cstring>
 #include <cstdlib>
 
-#if ( VAMP_SDK_MAJOR_VERSION != 2 || VAMP_SDK_MINOR_VERSION != 0 )
-#error Incorrect Vamp SDK header included (not the expected 2.0 SDK)
+#if ( VAMP_SDK_MAJOR_VERSION != 2 || VAMP_SDK_MINOR_VERSION != 4 )
+#error Unexpected version of Vamp SDK header included
 #endif
 
 
